/*
** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
** distribution information.
*/

#include	"auth.h"
#include	"authstaticlist.h"

static const char rcsid[]="$Id: authstaticlist.c,v 1.4 2000/04/27 02:51:00 mrsam Exp $";

/* First, prototype the functions */

#define	AUTHSTATIC(name, func, prefunc, cleanupfunc) \
	extern char *func(const char *, const char *, char *, int, \
			void (*)(struct authinfo *, void *), void *); \
	extern int prefunc(const char *, const char *, \
			int (*)(struct authinfo *, void *), void *arg); \
	extern void cleanupfunc();

STATIC_LIST

#undef	AUTHSTATIC

/* Now, we can build the list */

#define	AUTHSTATIC(name, func, prefunc, cleanupfunc) \
	{ name, func, prefunc, cleanupfunc, 0},

struct authstaticinfo authstaticlist[] = {

STATIC_LIST

	{0, 0, 0, 0} };
